from __future__ import absolute_import, division, print_function

__version__ = "0.4.0"
dependencies = ["flask==3.1.0",
                "huckle>=5.7.0,<6.0.0",
                "hcli_hai>=3.4.2,<4.0.0"]
